@@ -208,6 +208,12 @@ fn test_color_hex() {
     assert_eq!(c.g, 212.0 / 255.0);
     assert_eq!(c.b, 1.0);
     assert_eq!(c.a, 1.0);
+
+    let c = Color::hex_const("#00D4FF");
+    assert_eq!(c.r, 0.0);
+    assert_eq!(c.g, 0.831373);
+    assert_eq!(c.b, 1.0);
+    assert_eq!(c.a, 1.0);
 }
 
 #[test]
